==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridResourceStringsDescription } from "./WebGridResourceStringsDescription";
/**
 * @hidden
 */
export let WebGridResourceStringsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridResourceStringsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridResourceStringsDescriptionMetadata.a == null) {
                WebGridResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridResourceStringsDescriptionMetadata.c(WebGridResourceStringsDescriptionMetadata.a);
            }
            if (a.j(WebGridResourceStringsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridResourceStringsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridResourceStrings");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Igx_grid_groupByArea_message", "String");
            a.item("Igx_grid_groupByArea_select_message", "String");
            a.item("Igx_grid_groupByArea_deselect_message", "String");
            a.item("Igx_grid_emptyFilteredGrid_message", "String");
            a.item("Igx_grid_emptyGrid_message", "String");
            a.item("Igx_grid_filter", "String");
            a.item("Igx_grid_filter_row_close", "String");
            a.item("Igx_grid_filter_row_reset", "String");
            a.item("Igx_grid_filter_row_placeholder", "String");
            a.item("Igx_grid_filter_row_boolean_placeholder", "String");
            a.item("Igx_grid_filter_row_date_placeholder", "String");
            a.item("Igx_grid_filter_row_time_placeholder", "String");
            a.item("Igx_grid_filter_operator_and", "String");
            a.item("Igx_grid_complex_filter", "String");
            a.item("Igx_grid_filter_operator_or", "String");
            a.item("Igx_grid_filter_contains", "String");
            a.item("Igx_grid_filter_doesNotContain", "String");
            a.item("Igx_grid_filter_startsWith", "String");
            a.item("Igx_grid_filter_endsWith", "String");
            a.item("Igx_grid_filter_equals", "String");
            a.item("Igx_grid_filter_doesNotEqual", "String");
            a.item("Igx_grid_filter_empty", "String");
            a.item("Igx_grid_filter_notEmpty", "String");
            a.item("Igx_grid_filter_null", "String");
            a.item("Igx_grid_filter_notNull", "String");
            a.item("Igx_grid_filter_before", "String");
            a.item("Igx_grid_filter_after", "String");
            a.item("Igx_grid_filter_at", "String");
            a.item("Igx_grid_filter_not_at", "String");
            a.item("Igx_grid_filter_at_before", "String");
            a.item("Igx_grid_filter_at_after", "String");
            a.item("Igx_grid_filter_today", "String");
            a.item("Igx_grid_filter_yesterday", "String");
            a.item("Igx_grid_filter_thisMonth", "String");
            a.item("Igx_grid_filter_lastMonth", "String");
            a.item("Igx_grid_filter_nextMonth", "String");
            a.item("Igx_grid_filter_thisYear", "String");
            a.item("Igx_grid_filter_lastYear", "String");
            a.item("Igx_grid_filter_nextYear", "String");
            a.item("Igx_grid_filter_greaterThan", "String");
            a.item("Igx_grid_filter_lessThan", "String");
            a.item("Igx_grid_filter_greaterThanOrEqualTo", "String");
            a.item("Igx_grid_filter_lessThanOrEqualTo", "String");
            a.item("Igx_grid_filter_true", "String");
            a.item("Igx_grid_filter_false", "String");
            a.item("Igx_grid_filter_all", "String");
            a.item("Igx_grid_filter_condition_placeholder", "String");
            a.item("Igx_grid_summary_count", "String");
            a.item("Igx_grid_summary_min", "String");
            a.item("Igx_grid_summary_max", "String");
            a.item("Igx_grid_summary_sum", "String");
            a.item("Igx_grid_summary_average", "String");
            a.item("Igx_grid_summary_earliest", "String");
            a.item("Igx_grid_summary_latest", "String");
            a.item("Igx_grid_excel_filter_moving_left", "String");
            a.item("Igx_grid_excel_filter_moving_left_short", "String");
            a.item("Igx_grid_excel_filter_moving_right", "String");
            a.item("Igx_grid_excel_filter_moving_right_short", "String");
            a.item("Igx_grid_excel_filter_moving_header", "String");
            a.item("Igx_grid_excel_filter_sorting_asc", "String");
            a.item("Igx_grid_excel_filter_sorting_asc_short", "String");
            a.item("Igx_grid_excel_filter_sorting_desc", "String");
            a.item("Igx_grid_excel_filter_sorting_desc_short", "String");
            a.item("Igx_grid_excel_filter_sorting_header", "String");
            a.item("Igx_grid_excel_filter_clear", "String");
            a.item("Igx_grid_excel_custom_dialog_add", "String");
            a.item("Igx_grid_excel_custom_dialog_clear", "String");
            a.item("Igx_grid_excel_custom_dialog_header", "String");
            a.item("Igx_grid_excel_cancel", "String");
            a.item("Igx_grid_excel_apply", "String");
            a.item("Igx_grid_excel_search_placeholder", "String");
            a.item("Igx_grid_excel_select_all", "String");
            a.item("Igx_grid_excel_select_all_search_results", "String");
            a.item("Igx_grid_excel_add_to_filter", "String");
            a.item("Igx_grid_excel_blanks", "String");
            a.item("Igx_grid_excel_hide", "String");
            a.item("Igx_grid_excel_show", "String");
            a.item("Igx_grid_excel_pin", "String");
            a.item("Igx_grid_excel_unpin", "String");
            a.item("Igx_grid_excel_select", "String");
            a.item("Igx_grid_excel_deselect", "String");
            a.item("Igx_grid_excel_text_filter", "String");
            a.item("Igx_grid_excel_number_filter", "String");
            a.item("Igx_grid_excel_date_filter", "String");
            a.item("Igx_grid_excel_boolean_filter", "String");
            a.item("Igx_grid_excel_currency_filter", "String");
            a.item("Igx_grid_excel_custom_filter", "String");
            a.item("Igx_grid_excel_no_matches", "String");
            a.item("Igx_grid_advanced_filter_title", "String");
            a.item("Igx_grid_advanced_filter_and_group", "String");
            a.item("Igx_grid_advanced_filter_or_group", "String");
            a.item("Igx_grid_advanced_filter_end_group", "String");
            a.item("Igx_grid_advanced_filter_create_and_group", "String");
            a.item("Igx_grid_advanced_filter_create_or_group", "String");
            a.item("Igx_grid_advanced_filter_and_label", "String");
            a.item("Igx_grid_advanced_filter_or_label", "String");
            a.item("Igx_grid_advanced_filter_add_condition", "String");
            a.item("Igx_grid_advanced_filter_ungroup", "String");
            a.item("Igx_grid_advanced_filter_delete", "String");
            a.item("Igx_grid_advanced_filter_delete_filters", "String");
            a.item("Igx_grid_advanced_filter_initial_text", "String");
            a.item("Igx_grid_advanced_filter_column_placeholder", "String");
            a.item("Igx_grid_advanced_filter_value_placeholder", "String");
            a.item("Igx_grid_pinned_row_indicator", "String");
            a.item("Igx_grid_hiding_check_all_label", "String");
            a.item("Igx_grid_hiding_uncheck_all_label", "String");
            a.item("Igx_grid_pinning_check_all_label", "String");
            a.item("Igx_grid_pinning_uncheck_all_label", "String");
            a.item("Igx_grid_row_edit_btn_done", "String");
            a.item("Igx_grid_row_edit_btn_cancel", "String");
            a.item("Igx_grid_toolbar_actions_filter_prompt", "String");
            a.item("Igx_grid_toolbar_pinning_button_tooltip", "String");
            a.item("Igx_grid_toolbar_hiding_button_tooltip", "String");
            a.item("Igx_grid_toolbar_pinning_title", "String");
            a.item("Igx_grid_toolbar_hiding_title", "String");
            a.item("Igx_grid_toolbar_advanced_filtering_button_tooltip", "String");
            a.item("Igx_grid_toolbar_advanced_filtering_button_label", "String");
            a.item("Igx_grid_toolbar_exporter_button_tooltip", "String");
            a.item("Igx_grid_toolbar_exporter_button_label", "String");
            a.item("Igx_grid_toolbar_exporter_excel_entry_text", "String");
            a.item("Igx_grid_toolbar_exporter_csv_entry_text", "String");
            a.item("Igx_grid_snackbar_addrow_label", "String");
            a.item("Igx_grid_snackbar_addrow_actiontext", "String");
            a.item("Igx_grid_actions_edit_label", "String");
            a.item("Igx_grid_actions_add_label", "String");
            a.item("Igx_grid_add_row_label", "String");
            a.item("Igx_grid_actions_add_child_label", "String");
            a.item("Igx_grid_actions_delete_label", "String");
            a.item("Igx_grid_actions_pin_label", "String");
            a.item("Igx_grid_actions_unpin_label", "String");
            a.item("Igx_grid_actions_jumpUp_label", "String");
            a.item("Igx_grid_actions_jumpDown_label", "String");
            a.item("Igx_grid_pivot_date_dimension_total", "String");
            a.item("Igx_grid_pivot_aggregate_count", "String");
            a.item("Igx_grid_pivot_aggregate_min", "String");
            a.item("Igx_grid_pivot_aggregate_max", "String");
            a.item("Igx_grid_pivot_aggregate_sum", "String");
            a.item("Igx_grid_pivot_aggregate_avg", "String");
            a.item("Igx_grid_pivot_aggregate_date_latest", "String");
            a.item("Igx_grid_pivot_aggregate_date_earliest", "String");
            a.item("Igx_grid_pivot_aggregate_time_latest", "String");
            a.item("Igx_grid_pivot_aggregate_time_earliest", "String");
            a.item("Igx_grid_pivot_empty_row_drop_area", "String");
            a.item("Igx_grid_pivot_empty_column_drop_area", "String");
            a.item("Igx_grid_pivot_empty_filter_drop_area", "String");
            a.item("Igx_grid_pivot_empty_value_drop_area", "String");
            a.item("Igx_grid_pivot_row_drop_chip", "String");
            a.item("Igx_grid_pivot_column_drop_chip", "String");
            a.item("Igx_grid_pivot_filter_drop_chip", "String");
            a.item("Igx_grid_pivot_value_drop_chip", "String");
            a.item("Igx_grid_pivot_empty_message", "String");
            a.item("Igx_grid_pivot_selector_filters", "String");
            a.item("Igx_grid_pivot_selector_rows", "String");
            a.item("Igx_grid_pivot_selector_columns", "String");
            a.item("Igx_grid_pivot_selector_values", "String");
            a.item("Igx_grid_pivot_selector_panel_empty", "String");
            a.item("Igx_grid_required_validation_error", "String");
            a.item("Igx_grid_min_validation_error", "String");
            a.item("Igx_grid_max_validation_error", "String");
            a.item("Igx_grid_min_length_validation_error", "String");
            a.item("Igx_grid_max_length_validation_error", "String");
            a.item("Igx_grid_email_validation_error", "String");
            a.item("Igx_grid_pattern_validation_error", "String");
        }
        static d(a) {
            WebGridResourceStringsDescriptionMetadata.b(a);
            a.aa("WebGridResourceStrings", () => new WebGridResourceStringsDescription());
            a.z("WebGridResourceStrings", WebGridResourceStringsDescriptionMetadata.a);
        }
    }
    WebGridResourceStringsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridResourceStringsDescriptionMetadata, 'WebGridResourceStringsDescriptionMetadata');
    WebGridResourceStringsDescriptionMetadata.a = null;
    return WebGridResourceStringsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridResourceStringsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridResourceStringsDescription } from "./WebGridResourceStringsDescription";
/**
 * @hidden
 */
export let WebGridResourceStringsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridResourceStringsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridResourceStringsDescriptionMetadata.a == null) {
                WebGridResourceStringsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridResourceStringsDescriptionMetadata.c(WebGridResourceStringsDescriptionMetadata.a);
            }
            if (a.k(WebGridResourceStringsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridResourceStringsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridResourceStrings");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Igx_grid_groupByArea_message", "String");
            a.item("Igx_grid_groupByArea_select_message", "String");
            a.item("Igx_grid_groupByArea_deselect_message", "String");
            a.item("Igx_grid_emptyFilteredGrid_message", "String");
            a.item("Igx_grid_emptyGrid_message", "String");
            a.item("Igx_grid_filter", "String");
            a.item("Igx_grid_filter_row_close", "String");
            a.item("Igx_grid_filter_row_reset", "String");
            a.item("Igx_grid_filter_row_placeholder", "String");
            a.item("Igx_grid_filter_row_boolean_placeholder", "String");
            a.item("Igx_grid_filter_row_date_placeholder", "String");
            a.item("Igx_grid_filter_row_time_placeholder", "String");
            a.item("Igx_grid_filter_operator_and", "String");
            a.item("Igx_grid_complex_filter", "String");
            a.item("Igx_grid_filter_operator_or", "String");
            a.item("Igx_grid_filter_contains", "String");
            a.item("Igx_grid_filter_doesNotContain", "String");
            a.item("Igx_grid_filter_startsWith", "String");
            a.item("Igx_grid_filter_endsWith", "String");
            a.item("Igx_grid_filter_equals", "String");
            a.item("Igx_grid_filter_doesNotEqual", "String");
            a.item("Igx_grid_filter_empty", "String");
            a.item("Igx_grid_filter_notEmpty", "String");
            a.item("Igx_grid_filter_null", "String");
            a.item("Igx_grid_filter_notNull", "String");
            a.item("Igx_grid_filter_before", "String");
            a.item("Igx_grid_filter_after", "String");
            a.item("Igx_grid_filter_at", "String");
            a.item("Igx_grid_filter_not_at", "String");
            a.item("Igx_grid_filter_at_before", "String");
            a.item("Igx_grid_filter_at_after", "String");
            a.item("Igx_grid_filter_today", "String");
            a.item("Igx_grid_filter_yesterday", "String");
            a.item("Igx_grid_filter_thisMonth", "String");
            a.item("Igx_grid_filter_lastMonth", "String");
            a.item("Igx_grid_filter_nextMonth", "String");
            a.item("Igx_grid_filter_thisYear", "String");
            a.item("Igx_grid_filter_lastYear", "String");
            a.item("Igx_grid_filter_nextYear", "String");
            a.item("Igx_grid_filter_greaterThan", "String");
            a.item("Igx_grid_filter_lessThan", "String");
            a.item("Igx_grid_filter_greaterThanOrEqualTo", "String");
            a.item("Igx_grid_filter_lessThanOrEqualTo", "String");
            a.item("Igx_grid_filter_true", "String");
            a.item("Igx_grid_filter_false", "String");
            a.item("Igx_grid_filter_all", "String");
            a.item("Igx_grid_filter_condition_placeholder", "String");
            a.item("Igx_grid_summary_count", "String");
            a.item("Igx_grid_summary_min", "String");
            a.item("Igx_grid_summary_max", "String");
            a.item("Igx_grid_summary_sum", "String");
            a.item("Igx_grid_summary_average", "String");
            a.item("Igx_grid_summary_earliest", "String");
            a.item("Igx_grid_summary_latest", "String");
            a.item("Igx_grid_excel_filter_moving_left", "String");
            a.item("Igx_grid_excel_filter_moving_left_short", "String");
            a.item("Igx_grid_excel_filter_moving_right", "String");
            a.item("Igx_grid_excel_filter_moving_right_short", "String");
            a.item("Igx_grid_excel_filter_moving_header", "String");
            a.item("Igx_grid_excel_filter_sorting_asc", "String");
            a.item("Igx_grid_excel_filter_sorting_asc_short", "String");
            a.item("Igx_grid_excel_filter_sorting_desc", "String");
            a.item("Igx_grid_excel_filter_sorting_desc_short", "String");
            a.item("Igx_grid_excel_filter_sorting_header", "String");
            a.item("Igx_grid_excel_filter_clear", "String");
            a.item("Igx_grid_excel_custom_dialog_add", "String");
            a.item("Igx_grid_excel_custom_dialog_clear", "String");
            a.item("Igx_grid_excel_custom_dialog_header", "String");
            a.item("Igx_grid_excel_cancel", "String");
            a.item("Igx_grid_excel_apply", "String");
            a.item("Igx_grid_excel_search_placeholder", "String");
            a.item("Igx_grid_excel_select_all", "String");
            a.item("Igx_grid_excel_select_all_search_results", "String");
            a.item("Igx_grid_excel_add_to_filter", "String");
            a.item("Igx_grid_excel_blanks", "String");
            a.item("Igx_grid_excel_hide", "String");
            a.item("Igx_grid_excel_show", "String");
            a.item("Igx_grid_excel_pin", "String");
            a.item("Igx_grid_excel_unpin", "String");
            a.item("Igx_grid_excel_select", "String");
            a.item("Igx_grid_excel_deselect", "String");
            a.item("Igx_grid_excel_text_filter", "String");
            a.item("Igx_grid_excel_number_filter", "String");
            a.item("Igx_grid_excel_date_filter", "String");
            a.item("Igx_grid_excel_boolean_filter", "String");
            a.item("Igx_grid_excel_currency_filter", "String");
            a.item("Igx_grid_excel_custom_filter", "String");
            a.item("Igx_grid_excel_no_matches", "String");
            a.item("Igx_grid_advanced_filter_title", "String");
            a.item("Igx_grid_advanced_filter_and_group", "String");
            a.item("Igx_grid_advanced_filter_or_group", "String");
            a.item("Igx_grid_advanced_filter_end_group", "String");
            a.item("Igx_grid_advanced_filter_create_and_group", "String");
            a.item("Igx_grid_advanced_filter_create_or_group", "String");
            a.item("Igx_grid_advanced_filter_and_label", "String");
            a.item("Igx_grid_advanced_filter_or_label", "String");
            a.item("Igx_grid_advanced_filter_add_condition", "String");
            a.item("Igx_grid_advanced_filter_ungroup", "String");
            a.item("Igx_grid_advanced_filter_delete", "String");
            a.item("Igx_grid_advanced_filter_delete_filters", "String");
            a.item("Igx_grid_advanced_filter_initial_text", "String");
            a.item("Igx_grid_advanced_filter_column_placeholder", "String");
            a.item("Igx_grid_advanced_filter_value_placeholder", "String");
            a.item("Igx_grid_pinned_row_indicator", "String");
            a.item("Igx_grid_hiding_check_all_label", "String");
            a.item("Igx_grid_hiding_uncheck_all_label", "String");
            a.item("Igx_grid_pinning_check_all_label", "String");
            a.item("Igx_grid_pinning_uncheck_all_label", "String");
            a.item("Igx_grid_row_edit_btn_done", "String");
            a.item("Igx_grid_row_edit_btn_cancel", "String");
            a.item("Igx_grid_toolbar_actions_filter_prompt", "String");
            a.item("Igx_grid_toolbar_pinning_button_tooltip", "String");
            a.item("Igx_grid_toolbar_hiding_button_tooltip", "String");
            a.item("Igx_grid_toolbar_pinning_title", "String");
            a.item("Igx_grid_toolbar_hiding_title", "String");
            a.item("Igx_grid_toolbar_advanced_filtering_button_tooltip", "String");
            a.item("Igx_grid_toolbar_advanced_filtering_button_label", "String");
            a.item("Igx_grid_toolbar_exporter_button_tooltip", "String");
            a.item("Igx_grid_toolbar_exporter_button_label", "String");
            a.item("Igx_grid_toolbar_exporter_excel_entry_text", "String");
            a.item("Igx_grid_toolbar_exporter_csv_entry_text", "String");
            a.item("Igx_grid_snackbar_addrow_label", "String");
            a.item("Igx_grid_snackbar_addrow_actiontext", "String");
            a.item("Igx_grid_actions_edit_label", "String");
            a.item("Igx_grid_actions_add_label", "String");
            a.item("Igx_grid_add_row_label", "String");
            a.item("Igx_grid_actions_add_child_label", "String");
            a.item("Igx_grid_actions_delete_label", "String");
            a.item("Igx_grid_actions_pin_label", "String");
            a.item("Igx_grid_actions_unpin_label", "String");
            a.item("Igx_grid_actions_jumpUp_label", "String");
            a.item("Igx_grid_actions_jumpDown_label", "String");
            a.item("Igx_grid_pivot_date_dimension_total", "String");
            a.item("Igx_grid_pivot_aggregate_count", "String");
            a.item("Igx_grid_pivot_aggregate_min", "String");
            a.item("Igx_grid_pivot_aggregate_max", "String");
            a.item("Igx_grid_pivot_aggregate_sum", "String");
            a.item("Igx_grid_pivot_aggregate_avg", "String");
            a.item("Igx_grid_pivot_aggregate_date_latest", "String");
            a.item("Igx_grid_pivot_aggregate_date_earliest", "String");
            a.item("Igx_grid_pivot_aggregate_time_latest", "String");
            a.item("Igx_grid_pivot_aggregate_time_earliest", "String");
            a.item("Igx_grid_pivot_empty_row_drop_area", "String");
            a.item("Igx_grid_pivot_empty_column_drop_area", "String");
            a.item("Igx_grid_pivot_empty_filter_drop_area", "String");
            a.item("Igx_grid_pivot_empty_value_drop_area", "String");
            a.item("Igx_grid_pivot_row_drop_chip", "String");
            a.item("Igx_grid_pivot_column_drop_chip", "String");
            a.item("Igx_grid_pivot_filter_drop_chip", "String");
            a.item("Igx_grid_pivot_value_drop_chip", "String");
            a.item("Igx_grid_pivot_empty_message", "String");
            a.item("Igx_grid_pivot_selector_filters", "String");
            a.item("Igx_grid_pivot_selector_rows", "String");
            a.item("Igx_grid_pivot_selector_columns", "String");
            a.item("Igx_grid_pivot_selector_values", "String");
            a.item("Igx_grid_pivot_selector_panel_empty", "String");
            a.item("Igx_grid_required_validation_error", "String");
            a.item("Igx_grid_min_validation_error", "String");
            a.item("Igx_grid_max_validation_error", "String");
            a.item("Igx_grid_min_length_validation_error", "String");
            a.item("Igx_grid_max_length_validation_error", "String");
            a.item("Igx_grid_email_validation_error", "String");
            a.item("Igx_grid_pattern_validation_error", "String");
            a.item("Igx_grid_pivot_no_aggregator", "String");
        }
        static d(a) {
            WebGridResourceStringsDescriptionMetadata.b(a);
            a.ac("WebGridResourceStrings", () => new WebGridResourceStringsDescription());
            a.ab("WebGridResourceStrings", WebGridResourceStringsDescriptionMetadata.a);
        }
    }
    WebGridResourceStringsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridResourceStringsDescriptionMetadata, 'WebGridResourceStringsDescriptionMetadata');
    WebGridResourceStringsDescriptionMetadata.a = null;
    return WebGridResourceStringsDescriptionMetadata;
})();
